developerscripttools.DeveloperScript
====================================

.. abjad-lineage:: abjad.tools.developerscripttools.DeveloperScript.DeveloperScript.DeveloperScript

.. autoclass:: abjad.tools.developerscripttools.DeveloperScript.DeveloperScript.DeveloperScript
   :noindex:

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.developerscripttools.DeveloperScript.DeveloperScript.DeveloperScript.alias
   :noindex:

.. autoattribute:: abjad.tools.developerscripttools.DeveloperScript.DeveloperScript.DeveloperScript.argument_parser
   :noindex:

.. autoattribute:: abjad.tools.developerscripttools.DeveloperScript.DeveloperScript.DeveloperScript.formatted_help
   :noindex:

.. autoattribute:: abjad.tools.developerscripttools.DeveloperScript.DeveloperScript.DeveloperScript.formatted_usage
   :noindex:

.. autoattribute:: abjad.tools.developerscripttools.DeveloperScript.DeveloperScript.DeveloperScript.formatted_version
   :noindex:

.. autoattribute:: abjad.tools.developerscripttools.DeveloperScript.DeveloperScript.DeveloperScript.long_description
   :noindex:

.. autoattribute:: abjad.tools.developerscripttools.DeveloperScript.DeveloperScript.DeveloperScript.program_name
   :noindex:

.. autoattribute:: abjad.tools.developerscripttools.DeveloperScript.DeveloperScript.DeveloperScript.scripting_group
   :noindex:

.. autoattribute:: abjad.tools.developerscripttools.DeveloperScript.DeveloperScript.DeveloperScript.short_description
   :noindex:

.. autoattribute:: abjad.tools.developerscripttools.DeveloperScript.DeveloperScript.DeveloperScript.storage_format
   :noindex:

.. autoattribute:: abjad.tools.developerscripttools.DeveloperScript.DeveloperScript.DeveloperScript.version
   :noindex:

Methods
-------

.. automethod:: abjad.tools.developerscripttools.DeveloperScript.DeveloperScript.DeveloperScript.process_args
   :noindex:

.. automethod:: abjad.tools.developerscripttools.DeveloperScript.DeveloperScript.DeveloperScript.setup_argument_parser
   :noindex:

Special Methods
---------------

.. automethod:: abjad.tools.developerscripttools.DeveloperScript.DeveloperScript.DeveloperScript.__call__
   :noindex:

.. automethod:: abjad.tools.developerscripttools.DeveloperScript.DeveloperScript.DeveloperScript.__eq__
   :noindex:

.. automethod:: abjad.tools.developerscripttools.DeveloperScript.DeveloperScript.DeveloperScript.__ge__
   :noindex:

.. automethod:: abjad.tools.developerscripttools.DeveloperScript.DeveloperScript.DeveloperScript.__gt__
   :noindex:

.. automethod:: abjad.tools.developerscripttools.DeveloperScript.DeveloperScript.DeveloperScript.__le__
   :noindex:

.. automethod:: abjad.tools.developerscripttools.DeveloperScript.DeveloperScript.DeveloperScript.__lt__
   :noindex:

.. automethod:: abjad.tools.developerscripttools.DeveloperScript.DeveloperScript.DeveloperScript.__ne__
   :noindex:

.. automethod:: abjad.tools.developerscripttools.DeveloperScript.DeveloperScript.DeveloperScript.__repr__
   :noindex:
